package Net::Async::Slack::Event::PrefChange;

use strict;
use warnings;

our $VERSION = '0.003'; # VERSION

use Net::Async::Slack::EventType;

=head1 NAME

Net::Async::Slack::Event::PrefChange - You have updated your preferences

=head1 DESCRIPTION

Example input data:

    {
        "type": "pref_change",
        "name": "messages_theme",
        "value": "dense"
    }


=cut

sub type { 'pref_change' }

1;

__END__

=head1 AUTHOR

Tom Molesworth <TEAM@cpan.org>

=head1 LICENSE

Copyright Tom Molesworth 2016-2019. Licensed under the same terms as Perl itself.
